The Topic Modeling Neural Toolkit (TMNT) provides an implementation for training
topic models as neural network-based variational auto-encoders.

Documentation can be found here: https://tmnt.readthedocs.io/en/latest/

Current version: 0.5